<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>MX Package Installer</source>
        <translation>MX Paket-installerare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Populära Program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Hantera populära paket&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1321"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1293"/>
        <source>= Installed packages</source>
        <translation>= Installerade paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation>Aktiverade Förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ta bort alla paket som är markerade som &amp;quot;autoremovable&amp;quot;. Om du vill hantera dem, välj Autoremovable i den dragbara markeringsrutan.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation>Autoremove paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1384"/>
        <source>Upgrade All</source>
        <translation>Uppgradera alla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>Installerade:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>Totalt antal paket:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Installera även &quot;Rekommenderade&quot; Paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>Uppgraderingsbara:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation>Göm library och utvecklare-paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <source>Refresh list</source>
        <translation>Förnya listan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrera paket enligt deras status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="2827"/>
        <source>All packages</source>
        <translation>Alla paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="2847"/>
        <source>Installed</source>
        <translation>Installerad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <source>Upgradable</source>
        <translation>Uppgraderingsbar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1282"/>
        <location filename="../mainwindow.cpp" line="2813"/>
        <location filename="../mainwindow.cpp" line="2849"/>
        <location filename="../mainwindow.cpp" line="2951"/>
        <location filename="../mainwindow.cpp" line="2952"/>
        <source>Not installed</source>
        <translation>Inte installerad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2786"/>
        <location filename="../mainwindow.cpp" line="2850"/>
        <location filename="../mainwindow.cpp" line="2936"/>
        <source>Autoremovable</source>
        <translation>Autoremovable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Paket som kan uppgraderas. Nyare version finns i valt förråd.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>Paketnamn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1513"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>MX Test Repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation>Förrådsversion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation>Installerad version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1196"/>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.cpp" line="113"/>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>For all users</source>
        <translation>För alla användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1205"/>
        <source>For current user</source>
        <translation>För nuvarande användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1213"/>
        <source>Remote (repo):</source>
        <translation>Fjärr (förråd):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <location filename="../mainwindow.ui" line="1252"/>
        <location filename="../mainwindow.cpp" line="2795"/>
        <source>All apps</source>
        <translation>Alla program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1257"/>
        <location filename="../mainwindow.cpp" line="2801"/>
        <source>All runtimes</source>
        <translation>Alla runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <location filename="../mainwindow.cpp" line="2807"/>
        <source>All available</source>
        <translation>Alla tillgängliga</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1267"/>
        <location filename="../mainwindow.cpp" line="2792"/>
        <source>Installed apps</source>
        <translation>Installerade program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1272"/>
        <location filename="../mainwindow.cpp" line="2789"/>
        <source>Installed runtimes</source>
        <translation>Installerade runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1277"/>
        <location filename="../mainwindow.cpp" line="2811"/>
        <location filename="../mainwindow.cpp" line="2944"/>
        <location filename="../mainwindow.cpp" line="2945"/>
        <source>All installed</source>
        <translation>Alla installerade</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1363"/>
        <source>Total items </source>
        <translation>Alla poster</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1377"/>
        <source>Installed apps:</source>
        <translation>Installerade program:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1429"/>
        <source>Advanced</source>
        <translation>Avancerat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Total installed size:</source>
        <translation>Total storlek installerad:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Remove unused runtimes</source>
        <translation>Ta bort oanvända runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1503"/>
        <source>Short Name</source>
        <translation>Kort Namn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1508"/>
        <source>Full Package Name</source>
        <translation>Fullt Paketnamn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1518"/>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1548"/>
        <location filename="../mainwindow.cpp" line="2505"/>
        <location filename="../mainwindow.cpp" line="2721"/>
        <source>Console Output</source>
        <translation>Terminal Output</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1554"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Respond here, or just press Enter</source>
        <translation>Svara här, eller tryck bara på Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1623"/>
        <location filename="../mainwindow.cpp" line="1178"/>
        <location filename="../mainwindow.cpp" line="2837"/>
        <location filename="../mainwindow.cpp" line="2845"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <location filename="../mainwindow.cpp" line="2941"/>
        <location filename="../mainwindow.cpp" line="3215"/>
        <source>Install</source>
        <translation>Installera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1629"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1648"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1657"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1689"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1692"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1698"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1736"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1739"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1745"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1761"/>
        <source>Uninstall</source>
        <translation>Avinstallera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1767"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Uninstalling packages...</source>
        <translation>Avinstallerar paket...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Kör operationer före avinstallering...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Running post-uninstall operations...</source>
        <translation>Kör efterinstallations-process...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="221"/>
        <source>Refreshing sources...</source>
        <translation>Uppdaterar källor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <location filename="../mainwindow.cpp" line="1226"/>
        <location filename="../mainwindow.cpp" line="1360"/>
        <location filename="../mainwindow.cpp" line="1526"/>
        <location filename="../mainwindow.cpp" line="1583"/>
        <location filename="../mainwindow.cpp" line="1881"/>
        <location filename="../mainwindow.cpp" line="2025"/>
        <location filename="../mainwindow.cpp" line="2356"/>
        <location filename="../mainwindow.cpp" line="2375"/>
        <location filename="../mainwindow.cpp" line="2481"/>
        <location filename="../mainwindow.cpp" line="2497"/>
        <location filename="../mainwindow.cpp" line="2589"/>
        <location filename="../mainwindow.cpp" line="2622"/>
        <location filename="../mainwindow.cpp" line="3035"/>
        <location filename="../mainwindow.cpp" line="3111"/>
        <location filename="../mainwindow.cpp" line="3141"/>
        <location filename="../mainwindow.cpp" line="3232"/>
        <location filename="../mainwindow.cpp" line="3253"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Det blev ett problem vid uppdatering av källorna. Några källor kanske inte har haft några uppdateringar. För mer info kolla:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Please wait...</source>
        <translation>Var vänlig vänta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Du kommer att använda MX Test-förråd, vars paket enbart är avsedda för testning. Det är möjligt att de får ditt system att sluta fungera, så du uppmanas att göra backup av systemet och enbart installera eller uppdatera ett paket i taget. Var vänlig ge feedback på forumet så paketet kan utvärderas innan det flyttas till Main.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1055"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Du är på väg att använda Debian Backports, som innehåller paket från nästa Debianutgåva (kallad &apos;testing&apos;), justerade och omkompilerade för användning i Debian stable. De kan inte testas lika noga som i de stabila utgåvorna av Debian och MX Linux, och kommer som de är, med risk för inkompatibilitet med andra komponenter i Debian stable. Använd försiktigt!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux inkluderar detta förråd av flatpaks enbart för anvädarnas bekvämlighet och är inte ansvarigt för funktionen av enskilda flatpaks. För mer information, se flatpaks i Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1071"/>
        <location filename="../mainwindow.cpp" line="3241"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Do not show this message again</source>
        <translation>Visa inte det här meddelandet igen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Följande paket valdes. Klicka för att se detaljer i ändringslistan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <location filename="../mainwindow.cpp" line="1361"/>
        <location filename="../mainwindow.cpp" line="1584"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet inte tillgängligt, kan inte ladda ner paketlistan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1230"/>
        <source>Installing packages...</source>
        <translation>Installerar paketen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1285"/>
        <source>Post-processing...</source>
        <translation>Efterbehandlar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1317"/>
        <source>Pre-processing for </source>
        <translation>Förbereder för</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1332"/>
        <source>Installing </source>
        <translation>Installerar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Post-processing for </source>
        <translation>Efterbehandlar för</translation>
    </message>
    <message>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="vanished">Ett fel uppstod vid skrivande av fil: %1. Var vänlig kontrollera att du har tillräckligt mycket ledigt utrymme på disken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1527"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Downloading package info...</source>
        <translation>Laddar ner paketinformation...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1882"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>dpkg-query kommandot gav ett fel. Var vänlig kör &apos;dpkg-query -W&apos; i en terminal och kolla resultatet..</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2026"/>
        <source>dpkg command returned an error, please run &apos;dpkg --list&apos; in terminal and check the output.</source>
        <translation>Kommandot dpkg gav ett fel, var vänlig kör &apos;dpkg --list&apos; i en terminal och kontrollera resultatet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2104"/>
        <location filename="../mainwindow.cpp" line="2191"/>
        <location filename="../mainwindow.cpp" line="2214"/>
        <source>Package info</source>
        <translation>Paketinformation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>More &amp;info...</source>
        <translation>Mer &amp;info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2152"/>
        <source>Packages to be installed: </source>
        <translation>Paket som ska installeras:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2340"/>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <location filename="../mainwindow.cpp" line="3032"/>
        <location filename="../mainwindow.cpp" line="3107"/>
        <location filename="../mainwindow.cpp" line="3135"/>
        <location filename="../mainwindow.cpp" line="3228"/>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2340"/>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <location filename="../mainwindow.cpp" line="2494"/>
        <location filename="../mainwindow.cpp" line="3032"/>
        <location filename="../mainwindow.cpp" line="3107"/>
        <location filename="../mainwindow.cpp" line="3135"/>
        <location filename="../mainwindow.cpp" line="3228"/>
        <location filename="../mainwindow.cpp" line="3250"/>
        <source>Processing finished successfully.</source>
        <translation>Processen framgångsrikt avslutad.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2357"/>
        <location filename="../mainwindow.cpp" line="2376"/>
        <location filename="../mainwindow.cpp" line="3036"/>
        <location filename="../mainwindow.cpp" line="3112"/>
        <location filename="../mainwindow.cpp" line="3142"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Problem hittade under installationen, var vänlig kolla terminal-output.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2386"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2387"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2389"/>
        <source>Package Installer for MX Linux</source>
        <translation>Paketinstallerare för MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2391"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2392"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2404"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2481"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Vi mötte ett problem vid avinstallering, var vänlig kolla output</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2494"/>
        <location filename="../mainwindow.cpp" line="3250"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2497"/>
        <location filename="../mainwindow.cpp" line="3253"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Vi stötte på ett problem när programmet avinstallerades</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2590"/>
        <location filename="../mainwindow.cpp" line="2623"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Kunde inte ladda ned paketlistan. Var vänlig kontrollera dina APT-källor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2662"/>
        <location filename="../mainwindow.cpp" line="2702"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak ej installerad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2663"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak är ej installerad.
OK att fortsätta och installera det?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2702"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak blev ej installerad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2725"/>
        <source>Needs re-login</source>
        <translation>Behöver logga in igen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2726"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Du kan behöva logga ut/logga in för att se installerade poster i menyn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2837"/>
        <location filename="../mainwindow.cpp" line="2845"/>
        <location filename="../mainwindow.cpp" line="2937"/>
        <source>Mark keep</source>
        <translation>Markera behåll</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Upgrade</source>
        <translation>Uppgradera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <source>Quit?</source>
        <translation>Avsluta?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3065"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Process körs fortfarande, att avsluta kan lämna systemet i ett instabilt tillstånd.&lt;p&gt;&lt;b&gt;Är du säker att du vill avsluta MX Paket-installerare?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3213"/>
        <source>Reinstall</source>
        <translation>Ominstallera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3233"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Problem upptäcktes vid sista operationen, var vänlig kontrollera  konsol-output.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3242"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Potentiellt dfarlig operation.
Var vänlig kontrollera listan över paket som ska tas bort noga.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Hantera Flatpak Fjärr</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>För alla användare</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>För nuvarande användare</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation>Skriv in Flatpak fjärr URL</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation>skriv in Flatpakref belägenhet för att installera program</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Lägg till eller ta bort flatpak fjärr (förråd), eller installera program med flatpakref URL eller sökväg</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation>Ta bort fjärr</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation>Lägg till fjärr</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation>Installera program</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Går ej att ta bort</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub är den huvudsakliga Flatpak fjärr och kommer inte att tas bort</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation>Fel vid tillägg av fjärr</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Kunde inte lägga till fjärr - kommandot gav ett fel. Var vänlig dubbelkolla fjärr-adressen och försök igen</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation>Tillägg av fjärr lyckades</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>Dpkg/apt databasen är låst av ett annat program: %1
Stäng programet, eller vänta tills det kört klart och försök igen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX Paket-Installerare är ett verktyg för att hantera paket för MX Linux
    - installerar populära program från olika källor
    - installerar program froån MX Test repo
    - installerar program från Debian Backports repo
    - installerar flatpaks</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Skippa online-kontroll om det felaktigt rapporteras brist på tillgång till internet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <location filename="../main.cpp" line="104"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
</context>
</TS>
